@@ -44,7 +44,7 @@ typedef struct PGLogicalSyncStatus
 #define SYNC_STATUS_INIT		'i'		/* Ask for sync. */
 #define SYNC_STATUS_STRUCTURE	's'     /* Sync structure */
 #define SYNC_STATUS_DATA		'd'		/* Data sync. */
-#define SYNC_STATUS_CONSTAINTS	'c'		/* Constraint sync (post-data structure). */
+#define SYNC_STATUS_CONSTRAINTS	'c'		/* Constraint sync (post-data structure). */
 #define SYNC_STATUS_SYNCWAIT	'w'		/* Table sync is waiting to get OK from main thread. */
 #define SYNC_STATUS_CATCHUP		'u'		/* Catching up. */
 #define SYNC_STATUS_SYNCDONE	'y'		/* Synchronization finished (at lsn). */
@@ -88,5 +88,9 @@ extern bool wait_for_sync_status_change(Oid subid, const char *nspname,
 extern void truncate_table(char *nspname, char *relname);
 extern List *get_subscription_tables(Oid subid);
 
+#ifdef WIN32
+extern void QuoteWindowsArgv(StringInfo cmdline, const char * argv[]);
+#endif
+
 #endif /* PGLOGICAL_SYNC_H */
 
